@@ -2,7 +2,31 @@
 #include <Python.h>
 #include <stdlib.h>
 #include <string.h>
-#include <listobject.c>
+#include <listobject.h>
+
+int Get_minrun(char path[], int size_of_array)
+{
+    char line[30] = {0};
+    int line_count = -3;
+
+    FILE *file = fopen(path, "r");
+
+    int first_size = 0, step = 1;
+    int minrun = 2;
+    while (fgets(line, 30, file))
+    {
+        if (line_count == -3) {
+            first_size = atoi(line);
+        } else if (line_count == -2) {
+            step = atoi(line);
+        } else if (line_count >= 0 && first_size + line_count * step == size_of_array) {
+            minrun = atoi(line);
+        }
+        line_count++;
+    }
+    fclose(file);
+    return minrun;
+}
 
 static PyObject *
 timsort(PyObject *self, PyObject *args)
